@@ -1,4 +1,3 @@
-#!/usr/bin/python3
 """
 This script contains functions for compiling a dense configuration file into a list of configurations.
 """
@@ -19,10 +18,10 @@ from copy import deepcopy
 
 import nestifydict as nd
 
-from sample import *
+from .sample import *
 
 __all__ = ["compile_to_list", "compile_as_generator"]
-    
+
 def compile_to_list(config : dict):
     """
     Compiles dense configuration to get list of all sets of configurations
